package Qt::Core::QAtomicInt;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QAtomicInt
# file     : QtCore/qatomic.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QBasicAtomicInt/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Core::QAtomicInt

=head1 PUBLIC METHODS

=over

=item   QAtomicInt(int value)

=item   QAtomicInt(int value = 0)

=item   QAtomicInt(const QAtomicInt & other)

=item  QAtomicInt & operator=(int value)

=item  QAtomicInt & operator=(const QAtomicInt & other)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
